@@ -4,7 +4,7 @@ from decimal import Decimal, InvalidOperation
 
 from django import forms
 from django.contrib.admin.widgets import AdminDateWidget, \
-        AdminIntegerFieldWidget, AdminTimeWidget
+    AdminIntegerFieldWidget, AdminTimeWidget
 from django.core import exceptions, validators
 from django.core.exceptions import ValidationError
 from django.utils import formats
@@ -17,18 +17,19 @@ class AdminSplitDateTime(forms.SplitDateTimeWidget):
     A SplitDateTime Widget that has some admin-specific styling.
     """
     def __init__(self, attrs=None):
-        widgets = [AdminDateWidget, AdminTimeWidget, AdminDateWidget, \
-                AdminTimeWidget]
+        widgets = [
+            AdminDateWidget, AdminTimeWidget, AdminDateWidget, AdminTimeWidget
+        ]
         forms.MultiWidget.__init__(self, widgets, attrs)
 
     def format_output(self, rendered_widgets):
         return mark_safe(u'<p class="datetime">%s %s %s %s</p>\
-                <p class="datetime">%s %s %s %s</p>' % (
-                    _('Start Date:'), rendered_widgets[0],
-                    _(' Start Time:'), rendered_widgets[1],
-                    _('End Date:'), rendered_widgets[2],
-                    _('End Time:'), rendered_widgets[3])
-                )
+                         <p class="datetime">%s %s %s %s</p>' % (
+            _('Start Date:'), rendered_widgets[0],
+            _(' Start Time:'), rendered_widgets[1],
+            _('End Date:'), rendered_widgets[2],
+            _('End Time:'), rendered_widgets[3]
+        ))
 
 
 class AdminSplitDate(forms.SplitDateTimeWidget):
@@ -70,8 +71,9 @@ class AdminSplitInteger(forms.SplitDateTimeWidget):
         forms.MultiWidget.__init__(self, widgets, attrs)
 
     def format_output(self, rendered_widgets):
-        return mark_safe(u'<p class="datetime">%s %s %s %s</p>' % \
-            (_('Min:'), rendered_widgets[0], _('Max:'), rendered_widgets[1]))
+        return mark_safe(u'<p class="datetime">%s %s %s %s</p>' % (
+            _('Min:'), rendered_widgets[0], _('Max:'), rendered_widgets[1]
+        ))
 
 
 class BasicTextField(forms.fields.CharField):
@@ -79,8 +81,8 @@ class BasicTextField(forms.fields.CharField):
         super(BasicTextField, self).__init__(
             required=False,
             help_text="Only objects containing the entered text in its '%s' \
-                    field will be exported. Case is ignored." % \
-                    field.label.lower(),
+                      field will be exported. Case is ignored." % (
+            field.label.lower()),
             *args, **kwargs
         )
 
@@ -94,8 +96,8 @@ class BooleanField(forms.fields.ChoiceField):
         super(BooleanField, self).__init__(
             required=False,
             help_text="Only objects having its '%s' field set as selected will\
-                    be exported. Select 'Either' to ignore." % \
-                    field.label.lower(),
+                    be exported. Select 'Either' to ignore." % (
+            field.label.lower()),
             choices=(
                 ("", "Either"),
                 (True, "Yes"),
@@ -175,8 +177,9 @@ class DateField(forms.fields.DateField):
         for format in self.input_formats or formats.get_format(\
                 'DATE_INPUT_FORMATS'):
             try:
-                end_date = datetime.datetime(*time.strptime(end_value, \
-                        format)[:6]).date()
+                end_date = datetime.datetime(
+                    *time.strptime(end_value, format)[:6]
+                ).date()
             except ValueError:
                 continue
 
@@ -258,6 +261,14 @@ class DateTimeField(forms.fields.DateTimeField):
         return queryset.filter(**kwargs)
 
 
+class Field(forms.fields.Field):
+    def __init__(self, field, *args, **kwargs):
+        super(Field, self).__init__(
+            required=False,
+            *args, **kwargs
+        )
+
+
 class FileField(BasicTextField):
     pass
 
@@ -292,14 +303,12 @@ class IntegerField(forms.fields.IntegerField):
             try:
                 min = int(value[0])
             except (TypeError, ValueError):
-                raise exceptions.ValidationError(\
-                        self.error_messages['invalid'])
+                raise exceptions.ValidationError(self.error_messages['invalid'])
         if value[1] not in validators.EMPTY_VALUES:
             try:
                 max = int(value[1])
             except (TypeError, ValueError):
-                raise exceptions.ValidationError(\
-                        self.error_messages['invalid'])
+                raise exceptions.ValidationError(self.error_messages['invalid'])
 
         return (min, max)
 
@@ -340,16 +349,14 @@ class FloatField(forms.fields.FloatField):
             try:
                 min = float(value[0])
             except (TypeError, ValueError):
-                raise exceptions.ValidationError(\
-                        self.error_messages['invalid'])
+                raise exceptions.ValidationError(self.error_messages['invalid'])
         if value[1] not in validators.EMPTY_VALUES:
             try:
                 max = float(value[1])
             except (TypeError, ValueError):
-                raise exceptions.ValidationError(\
-                        self.error_messages['invalid'])
+                raise exceptions.ValidationError(self.error_messages['invalid'])
 
-        return (min, max)
+        return min, max
 
     def filter(self, name, value, queryset):
         kwargs = {}
@@ -392,16 +399,14 @@ class DecimalField(forms.fields.DecimalField):
             try:
                 min = Decimal(value[0])
             except (TypeError, ValueError, InvalidOperation):
-                raise exceptions.ValidationError(\
-                        self.error_messages['invalid'])
+                raise exceptions.ValidationError(self.error_messages['invalid'])
         if value[1] not in validators.EMPTY_VALUES:
             try:
                 max = Decimal(value[1])
             except (TypeError, ValueError, InvalidOperation):
-                raise exceptions.ValidationError(\
-                        self.error_messages['invalid'])
+                raise exceptions.ValidationError(self.error_messages['invalid'])
 
-        return (min, max)
+        return min, max
 
     def validate(self, value):
         if value in validators.EMPTY_VALUES:
@@ -448,24 +453,6 @@ class IPAddressField(BasicTextField):
     pass
 
 
-"""
-class ModelChoiceField(forms.models.ModelChoiceField):
-    def __init__(self, field, queryset, *args, **kwargs):
-        super(ModelChoiceField, self).__init__(
-            queryset=queryset,
-            required = False,
-            help_text="Only objects with relationships to the selected %s \
-                    above will be exported. Hold down 'Control', or 'Command' \
-                    on a Mac, to select more than one." % field.label.lower(),
-            *args, **kwargs
-        )
-
-    def filter(self, name, value, queryset):
-        kwargs = {name: value}
-        return queryset.filter(**kwargs)
-"""
-
-
 class ModelMultipleChoiceField(forms.models.ModelMultipleChoiceField):
     def __init__(self, field, queryset, *args, **kwargs):
         super(ModelMultipleChoiceField, self).__init__(
@@ -541,8 +528,9 @@ class TimeField(forms.fields.TimeField):
         for format in self.input_formats or formats.get_format(\
                 'TIME_INPUT_FORMATS'):
             try:
-                start_time = datetime.datetime(*time.strptime(start_value, \
-                        format)[:6]).time()
+                start_time = datetime.datetime(
+                    *time.strptime(start_value, format)[:6]
+                ).time()
             except ValueError:
                 if start_time:
                     continue
@@ -552,8 +540,9 @@ class TimeField(forms.fields.TimeField):
         for format in self.input_formats or formats.get_format(\
                 'TIME_INPUT_FORMATS'):
             try:
-                end_time = datetime.datetime(*time.strptime(end_value, \
-                        format)[:6]).time()
+                end_time = datetime.datetime(
+                    *time.strptime(end_value, format)[:6]
+                ).time()
             except ValueError:
                 if end_time:
                     continue
