@@ -8,8 +8,9 @@ from export import fields
 
 class Export(forms.Form):
     export_format = forms.ChoiceField(
-        choices=[(format, format) for format in \
-                serializers.get_serializer_formats()],
+        choices=[
+            (format, format) for format in serializers.get_serializer_formats()
+        ],
         required=False,
         label='Format',
         help_text='Designates export format.',
@@ -36,13 +37,19 @@ class Export(forms.Form):
 
     def __init__(self, model, *args, **kwargs):
         super(Export, self).__init__(*args, **kwargs)
-        self.fieldsets = (('Options', {'fields': ('export_format', \
-                'export_fields', 'export_order_by', \
-                'export_order_direction')}), ('Filters', \
-                {'description': 'Objects will be filtered to match the \
-                criteria as specified in the fields below. If a value \
-                is not specified for a field the field is ignored during \
-                the filter process.', 'fields': []}))
+        self.fieldsets = (
+            ('Options', {'fields': (
+                'export_format',
+                'export_fields', 'export_order_by',
+                'export_order_direction'
+            )}),
+            ('Filters', {
+                'description': 'Objects will be filtered to match the criteria \
+                as specified in the fields below. If a value is not specified \
+                for a field the field is ignored during the filter process.',
+                'fields': []
+            })
+        )
 
         field_choices = []
         form_fields = forms.models.fields_for_model(model)
@@ -51,20 +58,23 @@ class Export(forms.Form):
             if name not in form_fields.keys():
                 continue
             form_field = form_fields[name]
-            if form_field.__class__ in [forms.models.ModelChoiceField, \
-                    forms.models.ModelMultipleChoiceField]:
-                self.fields[name] = getattr(fields, field.__class__.\
-                        __name__)(form_field, form_field.queryset)
+            if form_field.__class__ in [forms.models.ModelChoiceField,
+                                        forms.models.ModelMultipleChoiceField]:
+                self.fields[name] = getattr(
+                    fields, field.__class__.__name__
+                )(form_field, form_field.queryset)
             else:
                 try:
-                    self.fields[name] = getattr(fields, \
-                            field.__class__.__name__)(form_field)
+                    self.fields[name] = getattr(
+                        fields, field.__class__.__name__
+                    )(form_field)
                 except AttributeError:
                     for parent_field in inspect.getmro(field.__class__):
                         if parent_field.__module__ == \
                                 'django.db.models.fields':
-                            self.fields[name] = getattr(\
-                                    fields, parent_field.__name__)(form_field)
+                            self.fields[name] = getattr(
+                                fields, parent_field.__name__
+                            )(form_field)
                             break
 
             if name not in self.fieldsets[1][1]['fields']:
