@@ -2,6 +2,6 @@ from export.utils import mail_export
 
 try:
     from celery import task
-    mail_export = task(mail_export, serializer='json')
+    mail_export = task(mail_export)
 except ImportError:
     pass
